@@ -1,11 +1,16 @@
-#' Transform the simulation object to include only the min, max, and the lower and upper bounds of the middle 50 percent
+#' Transform the simulation object to include only the min, max, and the lower 
+#' and upper bounds of the middle 50 percent
 #'
-#' \code{MinMaxLines} is an internal function to transform the simulation object to include only the min, max, and the lower and upper bounds of the middle 50 percent.
+#' \code{MinMaxLines} is an internal function to transform the simulation 
+#' object to include only the min, max, and the lower and upper bounds of the 
+#' middle 50 percent.
 #'
-#' @param df the data frame created by the simGG method from a simulation class object.
+#' @param df the data frame created by the simGG method from a simulation class 
+#' object.
 #' @param byVars character vector of the variables to subset the data frame by.
 #' @param hr logical indicating whether or not \code{df} contains a hazard rate.
-#' @param strata logical indicating whether or not \code{df} contains a stratified hazard rate. 
+#' @param strata logical indicating whether or not \code{df} contains a 
+#' stratified hazard rate. 
 #'
 #' @importFrom plyr ddply
 #' @keywords internals
@@ -23,8 +28,10 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE){
 		Linesdf <- ddply(df, byVars, transform, Median = median(QI))
 		Linesdf <- ddply(Linesdf, byVars, transform, Max = max(QI))
 		Linesdf <- ddply(Linesdf, byVars, transform, Min = min(QI))
-		Linesdf <- ddply(Linesdf, byVars, transform, Lower50 = quantile(QI, 0.25))
-		Linesdf <- ddply(Linesdf, byVars, transform, Upper50 = quantile(QI, 0.75))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Lower50 = quantile(QI, 0.25))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Upper50 = quantile(QI, 0.75))
 
 		Linesdf <- Linesdf[!duplicated(Linesdf[, byVars]), ] 
 	}
@@ -32,8 +39,10 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE){
 		Linesdf <- ddply(df, byVars, transform, Median = median(HRate))
 		Linesdf <- ddply(Linesdf, byVars, transform, Max = max(HRate))
 		Linesdf <- ddply(Linesdf, byVars, transform, Min = min(HRate))
-		Linesdf <- ddply(Linesdf, byVars, transform, Lower50 = quantile(HRate, 0.25))
-		Linesdf <- ddply(Linesdf, byVars, transform, Upper50 = quantile(HRate, 0.75))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Lower50 = quantile(HRate, 0.25))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Upper50 = quantile(HRate, 0.75))
 
 		Linesdf <- Linesdf[!duplicated(Linesdf[, c(1, 3)]), ] 
 
@@ -42,10 +51,13 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE){
 		Linesdf <- ddply(df, byVars, transform, Median = median(HRate))
 		Linesdf <- ddply(Linesdf, byVars, transform, Max = max(HRate))
 		Linesdf <- ddply(Linesdf, byVars, transform, Min = min(HRate))
-		Linesdf <- ddply(Linesdf, byVars, transform, Lower50 = quantile(HRate, 0.25))
-		Linesdf <- ddply(Linesdf, byVars, transform, Upper50 = quantile(HRate, 0.75))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Lower50 = quantile(HRate, 0.25))
+		Linesdf <- ddply(Linesdf, byVars, transform, 
+						Upper50 = quantile(HRate, 0.75))
 
-		Linesdf <- Linesdf[!duplicated(Linesdf[, c("Time", "HRValue", "Strata")]), ] 		
+		Linesdf <- Linesdf[!duplicated(
+						   Linesdf[, c("Time", "HRValue", "Strata")]), ] 		
 	}
 	return(Linesdf)
 }
@@ -54,8 +66,10 @@ MinMaxLines <- function(df, byVars = "Xj", hr = FALSE, strata = FALSE){
 #' Create a variable of each simulation value's percentile in the distribution. 
 #'
 #' @param SimIn data frame of simulations.
-#' @param xaxis character string. The column that will form the x-axis in the plot.  
-#' @param yaxis character string. The column that will form the y-axis in the plot.  
+#' @param xaxis character string. The column that will form the x-axis in 
+#' the plot.  
+#' @param yaxis character string. The column that will form the y-axis in 
+#' the plot.  
 #'
 #' @importFrom dplyr group_by
 #' @importFrom dplyr mutate
